@@ -15,7 +15,7 @@ from .search import SearchMockDataByName
 from .bandwidth import Bandwidth, BandwidthTemplates
 from .status_bar import StatusBar
 from .snapshot_import import SanpshotImport, SnapShotImportDetail
-from .snapshot_export import SnapshotExportFromDM, SnapshotExportFromEvent
+from .snapshot_export import SnapshotExport
 from lyrebird.log import get_logger
 from lyrebird import application
 from flask import got_request_exception
@@ -69,8 +69,7 @@ api_source.add_resource(Checker, '/checker', '/checker/<string:checker_id>')
 api_source.add_resource(Bandwidth, '/bandwidth')
 api_source.add_resource(BandwidthTemplates, '/bandwidth_templates')
 api_source.add_resource(SanpshotImport, '/snapshot/import/<path:url>', '/snapshot/import')
-api_source.add_resource(SnapshotExportFromDM,  '/snapshot/export/dm')
-api_source.add_resource(SnapshotExportFromEvent, '/snapshot/export/event')
+api_source.add_resource(SnapshotExport, '/snapshot/export/event', '/snapshot/export/<string:group_id>')
 api_source.add_resource(SnapShotImportDetail, '/snapshot/detail')
 api_source.add_resource(
     Event,
